use Perl6::Form;

print $^STDOUT, < form
	'A left-justified field look like this: \{[[[[[[[[[[[}',
	'The escape character for formats is: \';
